gmeterpy.corrections.atmosphere
===============================

.. automodule:: gmeterpy.corrections.atmosphere

   
   
   .. rubric:: Functions

   .. autosummary::
   
      atmospheric_pressure_correction
      normal_pressure
   
   

   
   
   

   
   
   